@@ -365,9 +365,17 @@ def fixchr(sumstats,chrom="CHR",status="STATUS",add_prefix="",x=("X",23),y=("Y",
         if verbose: log.write("Start to fix chromosome notation...")
         if verbose: log.write(" -Current Dataframe shape :",len(sumstats)," x ", len(sumstats.columns))          
         
-        # convert to string datatype        
-        if sumstats.loc[:,chrom].dtype != "string":
+        # convert to string datatype
+        try:
+            if verbose: log.write(" -Checking CHR data type...")
+            if sumstats.loc[:,chrom].dtype == "string":
+                pass
+            else:
+                sumstats.loc[:,chrom] = sumstats.loc[:,chrom].astype("string")
+        except:
+            if verbose: log.write(" -Force converting to pd string data type...")
             sumstats.loc[:,chrom] = sumstats.loc[:,chrom].astype("string")
+        
         # check if CHR is numeric
         is_chr_fixed = sumstats[chrom].str.isnumeric()
         # fill NAs with False
@@ -378,7 +386,7 @@ def fixchr(sumstats,chrom="CHR",status="STATUS",add_prefix="",x=("X",23),y=("Y",
         if sum(is_chr_fixed)<len(sumstats):
             
             #extract the CHR number or X Y M MT
-            chr_extracted = sumstats.loc[~is_chr_fixed,chrom].str.extract(r'(chr)?([0-9]{1,2,3}|[XYM]|[MT])$',flags=re.IGNORECASE|re.ASCII)[1]
+            chr_extracted = sumstats.loc[~is_chr_fixed,chrom].str.extract(r'(chr)?([0-9]{1,3}|[XYM]|MT)$',flags=re.IGNORECASE|re.ASCII)[1]
             is_chr_fixable = ~chr_extracted.isna()
             if verbose: log.write(" -Vairants with fixable chromosome notations:",sum(is_chr_fixable))  
 
@@ -468,10 +476,10 @@ def fixpos(sumstats,pos="POS",status="STATUS",remove=False, verbose=True,limit=2
         is_pos_na = sumstats.loc[:,pos].isna()
         
         # check if POS is string
-        if pd.api.types.is_string_dtype(sumstats.loc[:,pos]):
+        if pd.api.types.is_string_dtype(sumstats[pos]):
             # if so, remove thousands separator
             if verbose: log.write(' -Removing thousands separator "," or underbar "_" ...')
-            sumstats.loc[~is_pos_na, pos] = sumstats.loc[~is_pos_na, pos].str.replace(",|_", "",regex=True)
+            sumstats.loc[~is_pos_na, pos] = sumstats.loc[~is_pos_na, pos].astype("string").str.replace(",|_", "",regex=True)
 
         # convert POS to integer
         try:
